You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flink.apache.org by fh...@apache.org on 2015/07/31 00:35:36 UTC

flink git commit: [FLINK-2238][api] Generalized fromCollection(Seq) to fromCollection(Iterable)

Repository: flink
Updated Branches:
  refs/heads/master 68b155931 -> 3c236b2c8


[FLINK-2238][api] Generalized fromCollection(Seq) to fromCollection(Iterable)

This closes #956


Project: http://git-wip-us.apache.org/repos/asf/flink/repo
Commit: http://git-wip-us.apache.org/repos/asf/flink/commit/3c236b2c
Tree: http://git-wip-us.apache.org/repos/asf/flink/tree/3c236b2c
Diff: http://git-wip-us.apache.org/repos/asf/flink/diff/3c236b2c

Branch: refs/heads/master
Commit: 3c236b2c89ed84cded0d056ac40fc728089c6f67
Parents: 68b1559
Author: Sachin Goel <sa...@gmail.com>
Authored: Thu Jul 30 13:54:26 2015 +0530
Committer: Fabian Hueske <fh...@apache.org>
Committed: Fri Jul 31 00:33:37 2015 +0200

----------------------------------------------------------------------
 .../scala/org/apache/flink/api/scala/ExecutionEnvironment.scala  | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flink/blob/3c236b2c/flink-scala/src/main/scala/org/apache/flink/api/scala/ExecutionEnvironment.scala
----------------------------------------------------------------------
diff --git a/flink-scala/src/main/scala/org/apache/flink/api/scala/ExecutionEnvironment.scala b/flink-scala/src/main/scala/org/apache/flink/api/scala/ExecutionEnvironment.scala
index 28e8458..d53c54c 100644
--- a/flink-scala/src/main/scala/org/apache/flink/api/scala/ExecutionEnvironment.scala
+++ b/flink-scala/src/main/scala/org/apache/flink/api/scala/ExecutionEnvironment.scala
@@ -455,13 +455,13 @@ class ExecutionEnvironment(javaEnv: JavaEnv) {
   }
 
   /**
    * Creates a DataSet from the given non-empty [[Seq]].
    *
    * Note that this operation will result in a non-parallel data source, i.e. a data source with
    * a parallelism of one.
    */
   def fromCollection[T: ClassTag : TypeInformation](
-      data: Seq[T]): DataSet[T] = {
+      data: Iterable[T]): DataSet[T] = {
     require(data != null, "Data must not be null.")
 
     val typeInfo = implicitly[TypeInformation[T]]
@@ -455,13 +455,13 @@ class ExecutionEnvironment(javaEnv: JavaEnv) {
 
   /**
-   * Creates a DataSet from the given non-empty [[Seq]].
+   * Creates a DataSet from the given non-empty [[Iterable]].
    *
    * Note that this operation will result in a non-parallel data source, i.e. a data source with